Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys regen



details:   https://anonhg.NetBSD.org/src/rev/59331d4f99eb
branches:  trunk
changeset: 822409:59331d4f99eb
user:      riastradh <riastradh%NetBSD.org@localhost>
date:      Sat Mar 18 21:04:24 2017 +0000

description:
regen

diffstat:

 sys/rump/include/rump/rump_namei.h |   4 +-
 sys/sys/namei.h                    |  39 ++++++++++++++++++++++---------------
 2 files changed, 25 insertions(+), 18 deletions(-)

diffs (77 lines):

diff -r 339400c7201a -r 59331d4f99eb sys/rump/include/rump/rump_namei.h
--- a/sys/rump/include/rump/rump_namei.h        Sat Mar 18 21:04:12 2017 +0000
+++ b/sys/rump/include/rump/rump_namei.h        Sat Mar 18 21:04:24 2017 +0000
@@ -1,11 +1,11 @@
-/*     $NetBSD: rump_namei.h,v 1.28 2017/03/18 19:43:46 riastradh Exp $        */
+/*     $NetBSD: rump_namei.h,v 1.29 2017/03/18 21:04:24 riastradh Exp $        */
 
 
 /*
  * WARNING: GENERATED FILE.  DO NOT EDIT
  * (edit namei.src and run make namei in src/sys/sys)
  *   by:   NetBSD: gennameih.awk,v 1.5 2009/12/23 14:17:19 pooka Exp 
- *   from: NetBSD: namei.src,v 1.37 2015/04/21 03:18:21 riastradh Exp 
+ *   from: NetBSD: namei.src,v 1.39 2017/03/18 21:03:28 riastradh Exp 
  */
 
 #ifndef _RUMP_RUMP_NAMEI_H_
diff -r 339400c7201a -r 59331d4f99eb sys/sys/namei.h
--- a/sys/sys/namei.h   Sat Mar 18 21:04:12 2017 +0000
+++ b/sys/sys/namei.h   Sat Mar 18 21:04:24 2017 +0000
@@ -1,11 +1,11 @@
-/*     $NetBSD: namei.h,v 1.94 2017/03/18 19:43:46 riastradh Exp $     */
+/*     $NetBSD: namei.h,v 1.95 2017/03/18 21:04:24 riastradh Exp $     */
 
 
 /*
  * WARNING: GENERATED FILE.  DO NOT EDIT
  * (edit namei.src and run make namei in src/sys/sys)
  *   by:   NetBSD: gennameih.awk,v 1.5 2009/12/23 14:17:19 pooka Exp 
- *   from: NetBSD: namei.src,v 1.37 2015/04/21 03:18:21 riastradh Exp 
+ *   from: NetBSD: namei.src,v 1.39 2017/03/18 21:03:28 riastradh Exp 
  */
 
 /*
@@ -209,21 +209,28 @@
  * accessed and mostly read-only data is toward the front, with
  * infrequently accessed data and the lock towards the rear.  The
  * lock is then more likely to be in a seperate cache line.
+ *
+ * Locking rules:
+ *
+ *      -       stable after initialization
+ *      L       namecache_lock
+ *      C       struct nchcpu::cpu_lock
+ *      N       struct namecache::nc_lock
  */
-struct namecache {
-       LIST_ENTRY(namecache) nc_hash;  /* hash chain */
-       LIST_ENTRY(namecache) nc_vhash; /* directory hash chain */
-       struct  vnode *nc_dvp;          /* vnode of parent of name */
-       struct  vnode *nc_vp;           /* vnode the name refers to */
-       int     nc_flags;               /* copy of componentname's ISWHITEOUT */
-       char    nc_nlen;                /* length of name */
-       char    nc_name[NCHNAMLEN];     /* segment name */
-       void    *nc_gcqueue;            /* queue for garbage collection */
-       TAILQ_ENTRY(namecache) nc_lru;  /* psuedo-lru chain */
-       LIST_ENTRY(namecache) nc_dvlist;
-       LIST_ENTRY(namecache) nc_vlist;
-       kmutex_t nc_lock;               /* lock on this entry */
-       int     nc_hittime;             /* last time scored a hit */
+struct namecache {
+       LIST_ENTRY(namecache) nc_hash;  /* L hash chain */
+       LIST_ENTRY(namecache) nc_vhash; /* L directory hash chain */
+       struct  vnode *nc_dvp;          /* - vnode of parent of name */
+       struct  vnode *nc_vp;           /* - vnode the name refers to */
+       int     nc_flags;               /* - copy of componentname ISWHITEOUT */
+       char    nc_nlen;                /* - length of name */
+       char    nc_name[NCHNAMLEN];     /* - segment name */
+       void    *nc_gcqueue;            /* N queue for garbage collection */
+       TAILQ_ENTRY(namecache) nc_lru;  /* L psuedo-lru chain */
+       LIST_ENTRY(namecache) nc_dvlist;/* L dvp's list of cache entries */
+       LIST_ENTRY(namecache) nc_vlist; /* L vp's list of cache entries */
+       kmutex_t nc_lock;               /*   lock on this entry */
+       int     nc_hittime;             /* N last time scored a hit */
 };
 
 #ifdef _KERNEL



Home | Main Index | Thread Index | Old Index